// Let's define global variables for the height and width of the window.
var width = window.innerWidth;
var height = window.innerHeight;

// Let's define a scene, a camera and a renderer.
var scene = new THREE.Scene();
var camera = new THREE.PerspectiveCamera( 75, width / height, 0.1, 1000 );

var renderer = new THREE.WebGLRenderer();
renderer.setSize( width, height ); //Initialization of the renderer size.
document.body.appendChild( renderer.domElement );


//Resize the renderer and the camera aspect
window.addEventListener( 'resize', function( )
{
  var width = window.innerWidth;
  var height = window.innerHeight;
  renderer.setSize( width, height ); //Refresh the rendered size when the window size is changed.
  camera.aspect = width / height;
  camera.updateProjectionMatrix( );
} );

controls = new THREE.OrbitControls( camera, renderer.domElement );

// Create the shape
var geometry = new THREE.BoxGeometry( 1, 1, 1 );
var watermaterial = new THREE.MeshPhongMaterial( {map: new THREE.TextureLoader( ).load( "./texture/water.jpg" ), side:THREE.DoubleSide } );
var disturbmaterial = new THREE.MeshLambertMaterial( {map: new THREE.TextureLoader( ).load( "./texture/disturb.jpg" ), side:THREE.DoubleSide } );
var cubeMaterials =
[
  watermaterial,    // RIGHT SIDE
  watermaterial,    // LEFT SIDE
  disturbmaterial,  // TOP SIDE
  disturbmaterial,  // BOTTOM SIDE
  watermaterial,    // FRONT SIDE
  watermaterial     // BACK SIDE
];


var material = new THREE.MeshFaceMaterial( cubeMaterials );
var cube = new THREE.Mesh( geometry, material );
scene.add( cube );

camera.position.z = 3;

var ambientLight = new THREE.AmbientLight( 0xFFFFFF, 0.5 ); // soft white light (light color, intensity value)
scene.add( ambientLight );

// Game logic
var update = function( )
{
  cube.rotation.x += 0.01;
  cube.rotation.y += 0.05;
};

// Draw Scene
var render = function( )
{
  renderer.render( scene, camera );
};

// Run Game Loop (update, render, repeat)
var GameLoop = function( )
{
  requestAnimationFrame( GameLoop );

  update( );
  render( );
};

GameLoop( );
