// Let's define global variables for the height and width of the window.
var width = window.innerWidth;
var height = window.innerHeight;

// Let's define a scene, a camera and a renderer.
var scene = new THREE.Scene();
var camera = new THREE.PerspectiveCamera( 75, width / height, 0.1, 1000 );

var renderer = new THREE.WebGLRenderer();
renderer.setSize( width, height ); //Initialization of the renderer size.
document.body.appendChild( renderer.domElement );


//Resize the renderer and the camera aspect
window.addEventListener( 'resize', function( )
{
  var width = window.innerWidth;
  var height = window.innerHeight;
  renderer.setSize( width, height ); //Refresh the rendered size when the window size is changed.
  camera.aspect = width / height;
  camera.updateProjectionMatrix( );
} );

controls = new THREE.OrbitControls( camera, renderer.domElement );

// Create the shape
var geometry = new THREE.BoxGeometry( 1, 1, 1 );
var watermaterial = new THREE.MeshPhongMaterial( {map: new THREE.TextureLoader( ).load( "./texture/water.jpg" ), side:THREE.DoubleSide } );
var disturbmaterial = new THREE.MeshLambertMaterial( {map: new THREE.TextureLoader( ).load( "./texture/disturb.jpg" ), side:THREE.DoubleSide } );
var cubeMaterials =
[
  watermaterial,    // RIGHT SIDE
  watermaterial,    // LEFT SIDE
  disturbmaterial,  // TOP SIDE
  disturbmaterial,  // BOTTOM SIDE
  watermaterial,    // FRONT SIDE
  watermaterial     // BACK SIDE
];


var material = new THREE.MeshFaceMaterial( cubeMaterials );
var cube = new THREE.Mesh( geometry, material );
scene.add( cube );

camera.position.z = 3;

// Floor
var floorGeometry = new THREE.BoxGeometry( 20, 0.01, 20 );
var floorMaterial = new THREE.MeshPhongMaterial( {color: 0xffffff, wireframe: false, side:THREE.DoubleSide } );
var floorCube = new THREE.Mesh( floorGeometry, floorMaterial );
floorCube.position.y = -2;
scene.add( floorCube );

//LIGHTS
var ambientLight = new THREE.AmbientLight( 0xFFFFFF, 0.6 ); // soft ambient white light (light color, intensity value)
scene.add( ambientLight );

var light1 = new THREE.PointLight( 0xFF0040, 2, 50); // red point light (light color, intensity, distance until which objects are affected by light)
scene.add( light1 );

var light2 = new THREE.PointLight( 0x00FF40, 2, 50); // green point light (light color, intensity, distance until which objects are affected by light)
scene.add( light2 );

var light3 = new THREE.PointLight( 0x0040FF, 2, 50); // blue point light (light color, intensity, distance until which objects are affected by light)
scene.add( light3 );


// Game logic
var update = function( )
{
  cube.rotation.x += 0.01;
  cube.rotation.y += 0.05;

  var time = Date.now( ) * 0.0005;

  light1.position.x = Math.sin( time * 0.7 ) * 30;
  light1.position.y = Math.cos( time * 0.5 ) * 40;
  light1.position.z = Math.cos( time * 0.3 ) * 30;

  light2.position.x = Math.cos( time * 0.3 ) * 30;
  light2.position.y = Math.sin( time * 0.5 ) * 40;
  light2.position.z = Math.sin( time * 0.7 ) * 30;

  light3.position.x = Math.sin( time * 0.5 ) * 30;
  light3.position.y = Math.cos( time * 0.7 ) * 40;
  light3.position.z = Math.sin( time * 0.3 ) * 30;

};

// Draw Scene
var render = function( )
{
  renderer.render( scene, camera );
};

// Run Game Loop (update, render, repeat)
var GameLoop = function( )
{
  requestAnimationFrame( GameLoop );

  update( );
  render( );
};

GameLoop( );
